import { ContractRouter } from './contract.js';
import { ProfileRouter } from './profile.js';
type Fetcher = typeof fetch;
export declare class EscrowRouter {
    readonly host: string;
    readonly fetch: Fetcher;
    readonly _router: ContractRouter;
    readonly _profile: ProfileRouter;
    constructor(hostname: string, fetcher: Fetcher);
    get contract(): {
        list: () => Promise<import("../schema/types.js").ResponseAPI<{
            status: "draft" | "published" | "active" | "disputed" | "closed";
            updated_at: Date;
            info: {
                title: string;
                admin: string;
                agent: string;
                description?: string | undefined;
                terms?: string | undefined;
            };
            meta: {
                block_id: string;
                open_txid?: string | undefined;
                close_txid?: string | undefined;
            };
            room: {
                secret: string;
                nonce?: string | undefined;
                pubkey?: string | undefined;
                hash?: string | undefined;
            };
            members: string[];
            contract_id: string;
            revision: number;
            created_at: Date;
            endorsements: {
                pubkey: string;
                updated_at: Date;
                hash: string;
                signature: string;
            }[];
            profiles: {
                pubkey: string;
                updated_at: Date;
                nonce: string;
                alias: string;
            }[];
            records: {
                pubkey: string;
                kind: "data" | "script" | "term";
                label: string;
                content: string[];
                updated_at: Date;
            }[];
            signatures: {
                pubkey: string;
                updated_at: Date;
                hash: string;
                psig: string;
            }[];
            transactions: string[];
        }[]>>;
        create: (template: {
            title: string;
            description?: string | undefined;
            terms?: string | undefined;
            agent?: string | undefined;
            profile?: {
                nonce: string;
                alias: string;
            } | undefined;
            records?: {
                kind: "data" | "script" | "term";
                label: string;
                content: string[];
            }[] | undefined;
        }) => Promise<import("../schema/types.js").ResponseAPI<{
            status: "draft" | "published" | "active" | "disputed" | "closed";
            updated_at: Date;
            info: {
                title: string;
                admin: string;
                agent: string;
                description?: string | undefined;
                terms?: string | undefined;
            };
            meta: {
                block_id: string;
                open_txid?: string | undefined;
                close_txid?: string | undefined;
            };
            room: {
                secret: string;
                nonce?: string | undefined;
                pubkey?: string | undefined;
                hash?: string | undefined;
            };
            members: string[];
            contract_id: string;
            revision: number;
            created_at: Date;
            endorsements: {
                pubkey: string;
                updated_at: Date;
                hash: string;
                signature: string;
            }[];
            profiles: {
                pubkey: string;
                updated_at: Date;
                nonce: string;
                alias: string;
            }[];
            records: {
                pubkey: string;
                kind: "data" | "script" | "term";
                label: string;
                content: string[];
                updated_at: Date;
            }[];
            signatures: {
                pubkey: string;
                updated_at: Date;
                hash: string;
                psig: string;
            }[];
            transactions: string[];
        }>>;
        read: (contractId: string) => Promise<import("../schema/types.js").ResponseAPI<{
            status: "draft" | "published" | "active" | "disputed" | "closed";
            updated_at: Date;
            info: {
                title: string;
                admin: string;
                agent: string;
                description?: string | undefined;
                terms?: string | undefined;
            };
            meta: {
                block_id: string;
                open_txid?: string | undefined;
                close_txid?: string | undefined;
            };
            room: {
                secret: string;
                nonce?: string | undefined;
                pubkey?: string | undefined;
                hash?: string | undefined;
            };
            members: string[];
            contract_id: string;
            revision: number;
            created_at: Date;
            endorsements: {
                pubkey: string;
                updated_at: Date;
                hash: string;
                signature: string;
            }[];
            profiles: {
                pubkey: string;
                updated_at: Date;
                nonce: string;
                alias: string;
            }[];
            records: {
                pubkey: string;
                kind: "data" | "script" | "term";
                label: string;
                content: string[];
                updated_at: Date;
            }[];
            signatures: {
                pubkey: string;
                updated_at: Date;
                hash: string;
                psig: string;
            }[];
            transactions: string[];
        }>>;
        prune: () => Promise<import("../schema/types.js").ResponseAPI<any>>;
        update: (contractId: string, template: {
            title: string;
            description?: string | undefined;
            terms?: string | undefined;
            agent?: string | undefined;
        }) => Promise<import("../schema/types.js").ResponseAPI<any>>;
        cancel: (contractId: string) => Promise<import("../schema/types.js").ResponseAPI<any>>;
    };
    get endorse(): {
        update: (contractId: string, endorsement: string) => Promise<import("../schema/types.js").ResponseAPI<any>>;
        remove: (contractId: string) => Promise<import("../schema/types.js").ResponseAPI<any>>;
    };
    get members(): {
        update: (contractId: string, members: string[]) => Promise<import("../schema/types.js").ResponseAPI<any>>;
        remove: (contractId: string, members: string[]) => Promise<import("../schema/types.js").ResponseAPI<any>>;
    };
    get profile(): ProfileRouter;
    get records(): {
        update: (contractId: string, records: {
            kind: "data" | "script" | "term";
            label: string;
            content: string[];
        }[]) => Promise<import("../schema/types.js").ResponseAPI<any>>;
        remove: (contractId: string, queries: {
            label?: string | undefined;
            pubkey?: string | undefined;
            kind?: "data" | "script" | "term" | undefined;
        }[]) => Promise<import("../schema/types.js").ResponseAPI<any>>;
    };
    get sign(): {
        list: (contractId: string) => Promise<import("../schema/types.js").ResponseAPI<{
            pubkey: string;
            updated_at: Date;
            hash: string;
            psig: string;
        }[]>>;
        update: (contractId: string, signature: string) => Promise<import("../schema/types.js").ResponseAPI<any>>;
        remove: (contractId: string) => Promise<import("../schema/types.js").ResponseAPI<any>>;
    };
}
export {};
//# sourceMappingURL=index.d.ts.map